"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var styles_1 = require("./styles");
var utils_1 = require("./utils");
var NO_COLOR = 'transparent';
var MARKER_OFFSET = styles_1.MARKER_SIZE / 2;
exports.ColorPickerPalette = function (_a) {
    var _b = _a.dark, dark = _b === void 0 ? false : _b, _c = _a.styles, styles = _c === void 0 ? dark ? styles_1.darkStyles : styles_1.defaultStyles : _c, onSelectColor = _a.onSelectColor;
    var _d = React.useState(NO_COLOR), color = _d[0], setColor = _d[1];
    var _e = React.useState(), colorRGB = _e[0], setColorRGB = _e[1];
    var _f = React.useState(NO_COLOR), prevColor = _f[0], setPrevColor = _f[1];
    var _g = React.useState(null), markerX = _g[0], setMarkerX = _g[1];
    var _h = React.useState(null), markerY = _h[0], setMarkerY = _h[1];
    var canvasRef = React.createRef();
    var canvas = null;
    var ctx = null;
    var canvasRect = null;
    React.useEffect(function () {
        canvas = canvasRef.current;
        if (canvas) {
            ctx = canvas.getContext('2d');
            canvasRect = canvas.getBoundingClientRect();
            if (ctx && canvasRect) {
                var gradient = ctx.createLinearGradient(0, 0, canvas.width, 0);
                gradient.addColorStop(0, 'rgb(255, 0, 0)');
                gradient.addColorStop(0.15, 'rgb(255, 0, 255)');
                gradient.addColorStop(0.33, 'rgb(0, 0, 255)');
                gradient.addColorStop(0.49, 'rgb(0, 255, 255)');
                gradient.addColorStop(0.67, 'rgb(0, 255, 0)');
                gradient.addColorStop(0.84, 'rgb(255, 255, 0)');
                gradient.addColorStop(1, 'rgb(255, 0, 0)');
                ctx.fillStyle = gradient;
                ctx.fillRect(0, 0, ctx.canvas.width, canvas.height);
                gradient = ctx.createLinearGradient(0, 0, 0, canvas.height);
                gradient.addColorStop(0, 'rgba(255, 255, 255, 1)');
                gradient.addColorStop(0.03, 'rgba(255, 255, 255, 1)');
                gradient.addColorStop(0.5, 'rgba(255, 255, 255, 0)');
                gradient.addColorStop(0.5, 'rgba(0, 0, 0, 0)');
                gradient.addColorStop(1, 'rgba(0, 0, 0, 1)');
                ctx.fillStyle = gradient;
                ctx.fillRect(0, 0, ctx.canvas.width, ctx.canvas.height);
            }
        }
    });
    var selectColor = function (event) {
        if (canvas && ctx && canvasRect) {
            var colorX = event.clientX - canvasRect.left;
            var colorY = event.clientY - canvasRect.top;
            var imageData = ctx.getImageData(colorX, colorY, 1, 1);
            var r = imageData.data[0];
            var g = imageData.data[1];
            var b = imageData.data[2];
            var newRGB = [r, g, b];
            var newHex = utils_1.rgbToHex(newRGB);
            setColorRGB(newRGB);
            setPrevColor(color);
            setColor(newHex);
            utils_1.saveToClipboard(newHex);
            onSelectColor({ rgb: newRGB, hex: newHex });
        }
    };
    var setMarkerPos = function (e) {
        if (canvas && ctx && canvasRect) {
            setMarkerX(e.pageX - canvasRect.left / 2);
            setMarkerY(e.pageY - canvasRect.top / 2);
        }
    };
    return (React.createElement("div", { style: __assign({}, styles.colorPicker) },
        React.createElement("canvas", { "data-cy": "canvas", style: __assign({}, styles.canvas), width: styles.canvas.width, height: styles.canvas.height, ref: canvasRef, onClick: function (e) {
                selectColor(e);
                setMarkerPos(e);
            } }),
        markerX && markerY && (React.createElement("div", { "data-cy": "marker", style: __assign(__assign({}, styles.marker), { top: markerY + MARKER_OFFSET, left: markerX + MARKER_OFFSET }) })),
        React.createElement("div", { style: __assign({}, styles.results) },
            React.createElement("div", { style: __assign({}, styles.result) },
                React.createElement("div", { "data-cy": "result-hex" }, color === NO_COLOR ? '' : color)),
            React.createElement("div", { style: __assign({}, styles.result) },
                React.createElement("div", { "data-cy": "result-rgb" }, colorRGB && "rgb(" + colorRGB[0] + ", " + colorRGB[1] + ", " + colorRGB[2] + ")")),
            React.createElement("div", { style: __assign({}, styles.colors) },
                React.createElement("div", { "data-cy": "picked-color", onClick: function () { return utils_1.saveToClipboard(color); }, style: __assign(__assign({}, styles.color), { backgroundColor: color }) }),
                React.createElement("div", { "data-cy": "picked-prevColor", onClick: function () { return utils_1.saveToClipboard(prevColor); }, style: __assign(__assign({}, styles.prevColor), { backgroundColor: prevColor }) })))));
};
//# sourceMappingURL=ColorPickerPalette.js.map